package javax.sound.midi;

import java.io.IOException;
import java.io.InputStream;

public interface Sequencer extends MidiDevice
{
    public static final int LOOP_CONTINUOUSLY = -1;
    
    public abstract void setSequence(Sequence p0) throws InvalidMidiDataException;
    
    public abstract void setSequence(InputStream p0) throws IOException, InvalidMidiDataException;
    
    public abstract Sequence getSequence();
    
    public abstract void start();
    
    public abstract void stop();
    
    public abstract boolean isRunning();
    
    public abstract void startRecording();
    
    public abstract void stopRecording();
    
    public abstract boolean isRecording();
    
    public abstract void recordEnable(Track p0, int p1);
    
    public abstract void recordDisable(Track p0);
    
    public abstract float getTempoInBPM();
    
    public abstract void setTempoInBPM(float p0);
    
    public abstract float getTempoInMPQ();
    
    public abstract void setTempoInMPQ(float p0);
    
    public abstract void setTempoFactor(float p0);
    
    public abstract float getTempoFactor();
    
    public abstract long getTickLength();
    
    public abstract long getTickPosition();
    
    public abstract void setTickPosition(long p0);
    
    public abstract long getMicrosecondLength();
    
    public abstract long getMicrosecondPosition();
    
    public abstract void setMicrosecondPosition(long p0);
    
    public abstract void setMasterSyncMode(Sequencer.SyncMode p0);
    
    public abstract Sequencer.SyncMode getMasterSyncMode();
    
    public abstract Sequencer.SyncMode[] getMasterSyncModes();
    
    public abstract void setSlaveSyncMode(Sequencer.SyncMode p0);
    
    public abstract Sequencer.SyncMode getSlaveSyncMode();
    
    public abstract Sequencer.SyncMode[] getSlaveSyncModes();
    
    public abstract void setTrackMute(int p0, boolean p1);
    
    public abstract boolean getTrackMute(int p0);
    
    public abstract void setTrackSolo(int p0, boolean p1);
    
    public abstract boolean getTrackSolo(int p0);
    
    public abstract boolean addMetaEventListener(MetaEventListener p0);
    
    public abstract void removeMetaEventListener(MetaEventListener p0);
    
    public abstract int[] addControllerEventListener(ControllerEventListener p0, int[] p1);
    
    public abstract int[] removeControllerEventListener(ControllerEventListener p0, int[] p1);
    
    public abstract void setLoopStartPoint(long p0);
    
    public abstract long getLoopStartPoint();
    
    public abstract void setLoopEndPoint(long p0);
    
    public abstract long getLoopEndPoint();
    
    public abstract void setLoopCount(int p0);
    
    public abstract int getLoopCount();
    
    public static class SyncMode
    {
        private String name;
        public static final Sequencer.SyncMode INTERNAL_CLOCK;
        public static final Sequencer.SyncMode MIDI_SYNC;
        public static final Sequencer.SyncMode MIDI_TIME_CODE;
        public static final Sequencer.SyncMode NO_SYNC;
        
        protected SyncMode(String name) {
            this.name = name;
        }
        
        @Override
        public final boolean equals(Object obj) {
            return super.equals(obj);
        }
        
        @Override
        public final int hashCode() {
            return super.hashCode();
        }
        
        @Override
        public final String toString() {
            return this.name;
        }
        
        static {
            INTERNAL_CLOCK = new Sequencer.SyncMode("Internal Clock");
            MIDI_SYNC = new Sequencer.SyncMode("MIDI Sync");
            MIDI_TIME_CODE = new Sequencer.SyncMode("MIDI Time Code");
            NO_SYNC = new Sequencer.SyncMode("No Timing");
        }
    }
}
